package nz.co.sisu.dev.listener;

import javax.servlet.http.HttpSessionAttributeListener;
import javax.servlet.http.HttpSessionBindingEvent;

import com.sap.isa.core.SessionConst;
import com.sap.isa.core.UserSessionData;
import com.sap.isa.core.logging.IsaLocation;
import com.sap.isa.user.backend.ume.ISessionSecurityAuth;

import nz.co.sisu.dev.security.StubSessionSecurityAuth;

/**
 * Install a stub {@link com.sap.isa.user.backend.ume.ISessionSecurityAuth}
 * instance, which prevents UME related processing during login.
 * <p>
 * Without this {@link com.sap.isa.user.backend.ume.SessionSecurityAuthFactory}
 * will install {@link com.sap.isa.user.backend.ume.SessionSecurityAuthImpl},
 * which will attempt UME related login processing.
 */
public class UserSessionDataAttributeListener implements HttpSessionAttributeListener {

    private static IsaLocation log = IsaLocation.getInstance(UserSessionDataAttributeListener.class.getName());

    public void attributeAdded(HttpSessionBindingEvent event) {
        handleNewAttributeValue(event);
    }

    public void attributeReplaced(HttpSessionBindingEvent event) {
        handleNewAttributeValue(event);
    }

    public void attributeRemoved(HttpSessionBindingEvent event) {
        // nothing to do
    }

    private void handleNewAttributeValue(HttpSessionBindingEvent event) {
        if (SessionConst.USER_DATA.equals(event.getName())) {
            UserSessionData userData = UserSessionData.getUserSessionData(event.getSession());
            ISessionSecurityAuth currInst = (ISessionSecurityAuth) userData
                    .getAttribute(ISessionSecurityAuth.SESSION_AUTHENTICATOR);
            if (currInst == null) {
                log.debug("Installed stub ISessionSecurityAuth");
                userData.setAttribute(ISessionSecurityAuth.SESSION_AUTHENTICATOR, new StubSessionSecurityAuth());
            }
            else if (!StubSessionSecurityAuth.class.equals(currInst.getClass())) {
                log.warn("Unexpected ISessionSecurityAuth implementation: " + currInst.getClass().getName());
            }
        }
    }

}
