package nz.co.sisu.dev.security;

import java.util.Properties;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import com.sap.isa.core.logging.IsaLocation;
import com.sap.security.api.IAuthentication;
import com.sap.security.api.IUser;
import com.sap.security.api.UMException;

/**
 * Provides a stub implementation of {@link IAuthentication} for the local
 * development environment.
 * 
 * Used by the UME subsystem.
 */
public class StubAuthenticator implements IAuthentication {

    private static IsaLocation log = IsaLocation.getInstance(StubAuthenticator.class.getName());

    public void initialize(Properties properties) throws UMException {
        // method not required
        log.error("Unexpected call: initialize(Properties)");
        throw new UnsupportedOperationException();
    }

    public IUser forceLoggedInUser(HttpServletRequest req, HttpServletResponse resp) {
        // method not required
        log.error("Unexpected call: forceLoggedInUser(HttpServletRequest, HttpServletResponse)");
        throw new UnsupportedOperationException();
    }

    public IUser getLoggedInUser() {
        // method not required
        log.error("Unexpected call: getLoggedInUser()");
        throw new UnsupportedOperationException();
    }

    public IUser getLoggedInUser(HttpServletRequest req, HttpServletResponse resp) {
        // method not required
        log.error("Unexpected call: getLoggedInUser(HttpServletRequest, HttpServletResponse");
        throw new UnsupportedOperationException();
    }

    public void logout(HttpServletRequest req, HttpServletResponse resp) {
        // doesn't need to do anything in the Jetty dev environment
        log.debug("UME logout - stub implementation");
    }

    public void forceLogoffUser(HttpServletRequest req, HttpServletResponse resp, String url) {
        // method not required
        log.error("Unexpected call: forceLogoffUser(HttpServletRequest, HttpServletResponse, String)");
        throw new UnsupportedOperationException();
    }

}
